@@ -82,6 +82,9 @@ class QChemHarness(ProgramHarness):
             )
 
             mobj = re.search(r"Q-Chem\s+([\d.]+)\s+for", exc["stdout"])
+            if not mobj:
+                mobj = re.search(r"Q-Chem version:\s+([\d.]+)\s+", exc["stdout"])
+
             if mobj:
                 self.version_cache[which_prog] = safe_version(mobj.group(1))
 
@@ -202,7 +205,7 @@ class QChemHarness(ProgramHarness):
         elif input_model.driver == "hessian":
             keywords["JOBTYPE"] = "freq"
         else:
-            raise InputError(f"Driver of type {input_model.driver} is not yet supported.")
+            raise InputError(f"Driver {input_model.driver} not implemented for Q-Chem.")
 
         if input_model.molecule.fix_com or input_model.molecule.fix_orientation:
             keywords["SYM_IGNORE"] = "TRUE"
